@@ -1,7 +1,6 @@
 import base64
 import datetime as dt
 import json
-from dataclasses import asdict, dataclass, fields
 from io import BytesIO
 from typing import ClassVar, Dict, Generator, Optional, Union
 from urllib.parse import urlencode
@@ -13,21 +12,17 @@ from cuenca_validations.types import (
     TransactionQuery,
     TransactionStatus,
 )
+from pydantic import BaseModel
 
 from ..exc import MultipleResultsFound, NoResultFound
 from ..http import Session, session as global_session
 
 
-@dataclass
-class Resource:
+class Resource(BaseModel):
     _resource: ClassVar[str]
 
     id: str
 
-    # purely for MyPy
-    def __init__(self, **_):  # pragma: no cover
-        ...
-
     @classmethod
     def _from_dict(cls, obj_dict: Dict[str, Union[str, int]]) -> 'Resource':
         cls._filter_excess_fields(obj_dict)
@@ -40,12 +35,14 @@ class Resource:
         method allows the API to add fields in the response body without
         breaking the client
         """
-        excess = set(obj_dict.keys()) - {f.name for f in fields(cls)}
+        excess = set(obj_dict.keys()) - set(
+            cls.schema().get("properties").keys()
+        )
         for f in excess:
             del obj_dict[f]
 
     def to_dict(self):
-        return asdict(self, dict_factory=SantizedDict)
+        return SantizedDict(self.dict())
 
 
 class Retrievable(Resource):
@@ -69,8 +66,8 @@ class Creatable(Resource):
         return cls._from_dict(resp)
 
 
-@dataclass
 class Updateable(Resource):
+
     updated_at: dt.datetime
 
     @classmethod
@@ -81,7 +78,6 @@ class Updateable(Resource):
         return cls._from_dict(resp)
 
 
-@dataclass
 class Deactivable(Resource):
     deactivated_at: Optional[dt.datetime]
 
@@ -97,33 +93,31 @@ class Deactivable(Resource):
         return not self.deactivated_at
 
 
-@dataclass
 class Downloadable(Resource):
     @classmethod
     def download(
         cls,
-        instance,
-        file_format: FileFormat,
+        id: str,
+        file_format: FileFormat = FileFormat.any,
         *,
         session: Session = global_session,
     ) -> BytesIO:
         resp = session.request(
             'get',
-            f'/{cls._resource}/{instance.id}',
+            f'/{cls._resource}/{id}',
             headers=dict(Accept=file_format.value),
         )
         return BytesIO(resp)
 
     @property
     def pdf(self) -> bytes:
-        return self.download(self, file_format=FileFormat.pdf).read()
+        return self.download(self.id, file_format=FileFormat.pdf).read()
 
     @property
     def xml(self) -> bytes:
-        return self.download(self, file_format=FileFormat.xml).read()
+        return self.download(self.id, file_format=FileFormat.xml).read()
 
 
-@dataclass
 class Uploadable(Resource):
     @classmethod
     def _upload(
@@ -147,7 +141,6 @@ class Uploadable(Resource):
         return cls._from_dict(json.loads(resp))
 
 
-@dataclass
 class Queryable(Resource):
     _query_params: ClassVar = QueryParams
 
@@ -202,7 +195,6 @@ class Queryable(Resource):
             next_page_uri = page['next_page_uri']
 
 
-@dataclass
 class Transaction(Retrievable, Queryable):
     _query_params: ClassVar = TransactionQuery
 
@@ -212,7 +204,6 @@ class Transaction(Retrievable, Queryable):
     descriptor: str  # how it appears for the customer
 
 
-@dataclass
 class Wallet(Creatable, Deactivable, Retrievable, Queryable):
     user_id: str
     balance: int
