@@ -4,18 +4,17 @@ from typing import ClassVar, List, Optional, cast
 from clabe import Clabe
 from cuenca_validations.types import (
     Address,
-    AddressUpdateRequest,
     Beneficiary,
     KYCFile,
-    KYCFileUpdateRequest,
     PhoneNumber,
     TOSAgreement,
-    TOSUpdateRequest,
+    TOSRequest,
     UserQuery,
     UserRequest,
     UserStatus,
     UserUpdateRequest,
 )
+from cuenca_validations.types.enums import Country, Gender, State
 from cuenca_validations.types.identities import CurpField
 from pydantic import EmailStr
 
@@ -46,6 +45,17 @@ class User(Creatable, Retrievable, Updateable, Queryable):
     beneficiaries: Optional[List[Beneficiary]]
     platform_id: Optional[str] = None
     clabe: Optional[Clabe] = None
+    # These fields are added by identify when retrieving a User:
+    names: Optional[str]
+    first_surname: Optional[str]
+    second_surname: Optional[str]
+    curp: Optional[str]
+    rfc: Optional[str]
+    gender: Optional[Gender]
+    date_of_birth: Optional[dt.date]
+    state_of_birth: Optional[State]
+    nationality: Optional[Country]
+    country_of_birth: Optional[Country]
 
     @property
     def balance(self) -> int:
@@ -109,6 +119,7 @@ class User(Creatable, Retrievable, Updateable, Queryable):
         phone_verification_id: Optional[str] = None,
         status: Optional[UserStatus] = None,
         required_level: Optional[int] = None,
+        terms_of_service: Optional[TOSRequest] = None,
         *,
         session: Session = global_session,
     ) -> 'User':
@@ -122,6 +133,7 @@ class User(Creatable, Retrievable, Updateable, Queryable):
             phone_verification_id=phone_verification_id,
             required_level=required_level,
             status=status,
+            terms_of_service=terms_of_service,
         )
         return cast('User', cls._create(session=session, **req.dict()))
 
@@ -132,13 +144,16 @@ class User(Creatable, Retrievable, Updateable, Queryable):
         phone_number: Optional[PhoneNumber] = None,
         email_address: Optional[str] = None,
         profession: Optional[str] = None,
-        address: Optional[AddressUpdateRequest] = None,
+        address: Optional[Address] = None,
         beneficiaries: Optional[List[Beneficiary]] = None,
-        govt_id: Optional[KYCFileUpdateRequest] = None,
-        proof_of_address: Optional[KYCFileUpdateRequest] = None,
-        proof_of_life: Optional[KYCFileUpdateRequest] = None,
-        terms_of_service: Optional[TOSUpdateRequest] = None,
+        govt_id: Optional[KYCFile] = None,
+        proof_of_address: Optional[KYCFile] = None,
+        proof_of_life: Optional[KYCFile] = None,
+        terms_of_service: Optional[TOSRequest] = None,
         verification_id: Optional[str] = None,
+        status: Optional[UserStatus] = None,
+        email_verification_id: Optional[str] = None,
+        phone_verification_id: Optional[str] = None,
         *,
         session: Session = global_session,
     ):
@@ -153,6 +168,9 @@ class User(Creatable, Retrievable, Updateable, Queryable):
             proof_of_life=proof_of_life,
             terms_of_service=terms_of_service,
             verification_id=verification_id,
+            email_verification_id=email_verification_id,
+            phone_verification_id=phone_verification_id,
+            status=status,
         )
         return cast(
             'User',
